@@ -210,27 +210,27 @@ QT_BEGIN_NAMESPACE
 */
 
 /*!
-    \qmlproperty vector3d DynamicRigidBody::kinematicRotation
+    \qmlproperty quaternion DynamicRigidBody::kinematicRotation
     \since 6.5
 
     Defines the rotation of the object when it is kinematic, i.e. when \l isKinematic is set to \c
     true. On each iteration of the simulation the physical object will be updated according to this
     value.
 
-    Default value: \c{(0, 0, 0)}
+    Default value: \c{(1, 0, 0, 0)}
 
     \sa isKinematic, kinematicPosition, kinematicEulerRotation, kinematicPivot
 */
 
 /*!
-    \qmlproperty vector4d DynamicRigidBody::kinematicEulerRotation
+    \qmlproperty vector3d DynamicRigidBody::kinematicEulerRotation
     \since 6.5
 
     Defines the euler rotation of the object when it is kinematic, i.e. when \l isKinematic is set to \c
     true. On each iteration of the simulation the physical object will be updated according to this
     value.
 
-    Default value: \c{(1, 0, 0, 0)}
+    Default value: \c{(0, 0, 0)}
 
     \sa isKinematic, kinematicPosition, kinematicEulerRotation, kinematicPivot
 */
